@@ -1,6 +1,7 @@
 /*
  *  Copyright (c) 2009 Giuseppe Torelli <colossus73@gmail.com>
  *  Copyright (c) 2009 Tadej Borovšak 	<tadeboro@gmail.com>
+ *  Copyright (c) 2011 Robert Chéramy   <robert@cheramy.net>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -119,7 +120,11 @@ void img_set_window_title(img_window_struct *img, gchar *text)
 
 void img_new_slideshow(GtkMenuItem *item,img_window_struct *img_struct)
 {
-	img_new_slideshow_settings_dialog(img_struct, FALSE);
+    if (img_struct->project_is_modified)
+        if (GTK_RESPONSE_OK != img_ask_user_confirmation(img_struct, _("You didn't save your slideshow yet. Are you sure you want to close it?")))
+            return;
+	img_close_slideshow(GTK_WIDGET(item), img_struct);
+    img_new_slideshow_settings_dialog(img_struct, FALSE);
 }
 
 void img_project_properties(GtkMenuItem *item, img_window_struct *img_struct)
@@ -202,7 +207,8 @@ void img_increase_progressbar(img_window_struct *img, gint nr)
 
 	percent = (gdouble)nr / img->slides_nr;
 	gtk_progress_bar_set_fraction (GTK_PROGRESS_BAR (img->progress_bar), percent);
-	message = g_strdup_printf(_("Please wait, importing slide %d out of %d"), nr, img->slides_nr);
+	message = g_strdup_printf( _("Please wait, importing image %d out of %d"),
+							   nr, img->slides_nr );
 	gtk_statusbar_push(GTK_STATUSBAR(img->statusbar), img->context_id, message);
 	g_free(message);
 
@@ -230,7 +236,7 @@ void img_remove_audio_files (GtkWidget *widget, img_window_struct *img)
 	    {
 			if (gtk_tree_model_get_iter(GTK_TREE_MODEL(img->music_file_liststore), &iter, path))
 			{
-				gtk_tree_model_get(GTK_TREE_MODEL(img->music_file_liststore), &iter, 3, &secs, -1);
+                gtk_tree_model_get(GTK_TREE_MODEL(img->music_file_liststore), &iter, 3, &secs, -1);
 				gtk_list_store_remove(img->music_file_liststore, &iter);
 			}
 			gtk_tree_path_free(path);
@@ -239,6 +245,7 @@ void img_remove_audio_files (GtkWidget *widget, img_window_struct *img)
 	}
 	if (gtk_tree_model_get_iter_first(GTK_TREE_MODEL(img->music_file_liststore), &iter) == FALSE)
 	{
+        img_play_stop_selected_file(NULL, img);
 		gtk_widget_set_sensitive (img->remove_audio_button, FALSE);
 		gtk_widget_set_sensitive (img->play_audio_button, FALSE);
 		gtk_label_set_text(GTK_LABEL(img->music_time_data), "");
@@ -269,14 +276,15 @@ void img_select_audio_files_to_add ( GtkMenuItem* button, img_window_struct *img
 	gint response;
 	gchar *time = NULL;
 
-	fs = gtk_file_chooser_dialog_new (_("Please choose the audio files to import"),
-							GTK_WINDOW (img->imagination_window),
-							GTK_FILE_CHOOSER_ACTION_OPEN,
-							GTK_STOCK_CANCEL,
-							GTK_RESPONSE_CANCEL,
-							GTK_STOCK_OPEN,
-							GTK_RESPONSE_ACCEPT,
-							NULL);
+	fs = gtk_file_chooser_dialog_new( _("Import audio files, use CTRL key "
+										"for multiple select"),
+									  GTK_WINDOW (img->imagination_window),
+									  GTK_FILE_CHOOSER_ACTION_OPEN,
+									  GTK_STOCK_CANCEL,
+									  GTK_RESPONSE_CANCEL,
+									  GTK_STOCK_OPEN,
+									  GTK_RESPONSE_ACCEPT,
+									  NULL );
 
 	/* only audio files filter */
 	audio_filter = gtk_file_filter_new ();
@@ -344,14 +352,16 @@ GSList *img_import_slides_file_chooser(img_window_struct *img)
 	GSList *slides = NULL;
 	int response;
 
-	img->import_slide_chooser = gtk_file_chooser_dialog_new (_("Import slides, use SHIFT key for multiple select"),
-						GTK_WINDOW (img->imagination_window),
-						GTK_FILE_CHOOSER_ACTION_OPEN,
-						GTK_STOCK_CANCEL,
-						GTK_RESPONSE_CANCEL,
-						GTK_STOCK_OPEN,
-						GTK_RESPONSE_ACCEPT,
-						NULL);
+	img->import_slide_chooser =
+		gtk_file_chooser_dialog_new( _("Import images, use SHIFT key for "
+									   "multiple select"),
+									 GTK_WINDOW (img->imagination_window),
+									 GTK_FILE_CHOOSER_ACTION_OPEN,
+									 GTK_STOCK_CANCEL,
+									 GTK_RESPONSE_CANCEL,
+									 GTK_STOCK_OPEN,
+									 GTK_RESPONSE_ACCEPT,
+									 NULL);
 	img_file_chooser_add_preview(img);
 
 	/* Image files filter */
@@ -424,6 +434,12 @@ void img_free_allocated_memory(img_window_struct *img_struct)
 		g_free(img_struct->current_dir);
 		img_struct->current_dir = NULL;
 	}
+	
+	if (img_struct->project_current_dir)
+    {
+        g_free(img_struct->project_current_dir);
+        img_struct->project_current_dir = NULL;
+    }
 
 	if (img_struct->project_filename)
 	{
@@ -450,7 +466,7 @@ gboolean img_quit_application(GtkWidget *widget, GdkEvent *event, img_window_str
 
 	if (img_struct->project_is_modified)
 	{
-		response = img_ask_user_confirmation(img_struct, _("You didn't save your slideshow yet. Are you sure you want to close it?"));
+		response = img_ask_user_confirmation( img_struct, _("You didn't save your slideshow yet. Are you sure you want to close it?"));
 		if (response != GTK_RESPONSE_OK)
 			return TRUE;
 	}
@@ -769,7 +785,7 @@ void img_show_about_dialog (GtkMenuItem *item,img_window_struct *img_struct)
 {
 	static GtkWidget *about = NULL;
 	static gchar version[] = VERSION "-" REVISION;
-    const char *authors[] = {"\nDevelopers:\nGiuseppe Torelli <colossus73@gmail.com>\nTadej Borovšak <tadeboro@gmail.com>\n\nImagination logo:\nhttp://linuxgraphicsusers.com\n\nInsert Transitions Family:\nJean-Pierre Redonnet <inphilly@gmail.com>",NULL};
+    const char *authors[] = {"\nDevelopers:\nGiuseppe Torelli <colossus73@gmail.com>\nTadej Borovšak <tadeboro@gmail.com>\nRobert Chéramy <robert@cheramy.net>\n\nImagination logo:\nhttp://linuxgraphicsusers.com\n\nInsert Transitions Family:\nJean-Pierre Redonnet <inphilly@gmail.com>",NULL};
     //const char *documenters[] = {NULL};
 
 	if (about == NULL)
@@ -953,10 +969,10 @@ void img_start_stop_preview(GtkWidget *button, img_window_struct *img)
 
 		/* Add transition timeout function */
 		img->preview_is_running = TRUE;
-		img->total_nr_frames = img->total_secs * PREVIEW_FPS;
+		img->total_nr_frames = img->total_secs * img->preview_fps;
 		img->displayed_frame = 0;
 		img->next_slide_off = 0;
-		img_calc_next_slide_time_offset( img, PREVIEW_FPS );
+		img_calc_next_slide_time_offset( img, img->preview_fps );
 
 		/* Create surfaces to be passed to transition renderer */
 		img->image_from = cairo_image_surface_create( CAIRO_FORMAT_RGB24,
@@ -969,7 +985,7 @@ void img_start_stop_preview(GtkWidget *button, img_window_struct *img)
 														  img->video_size[0],
 														  img->video_size[1] );
 
-		img->source_id = g_timeout_add( 1000 / PREVIEW_FPS,
+		img->source_id = g_timeout_add( 1000 / img->preview_fps,
 										(GSourceFunc)img_transition_timeout,
 										img );
 	}
@@ -1217,6 +1233,7 @@ img_on_expose_event( GtkWidget         *widget,
 								 img->current_slide->subtitle,
 								 img->current_slide->font_desc,
 								 img->current_slide->font_color,
+                                 img->current_slide->font_bgcolor,
 								 img->current_slide->anim,
 								 1.0 );
 		
@@ -1271,7 +1288,7 @@ static gboolean img_transition_timeout(img_window_struct *img)
 	 * transition part), connect still preview phase. */
 	if( img->slide_cur_frame == img->slide_trans_frames )
 	{
-		img->source_id = g_timeout_add( 1000 / PREVIEW_FPS,
+		img->source_id = g_timeout_add( 1000 / img->preview_fps,
 										(GSourceFunc)img_still_timeout, img );
 
 		return FALSE;
@@ -1298,8 +1315,8 @@ static gboolean img_still_timeout(img_window_struct *img)
 	{
 		if( img_prepare_pixbufs( img, TRUE ) )
 		{
-			img_calc_next_slide_time_offset( img, PREVIEW_FPS );
-			img->source_id = g_timeout_add( 1000 / PREVIEW_FPS,
+			img_calc_next_slide_time_offset( img, img->preview_fps );
+			img->source_id = g_timeout_add( 1000 / img->preview_fps,
 										    (GSourceFunc)img_transition_timeout,
 											img );
 		}
@@ -1317,7 +1334,7 @@ static gboolean img_still_timeout(img_window_struct *img)
 	}
 
 	/* Render frame */
-	img_render_still_frame( img, PREVIEW_FPS );
+	img_render_still_frame( img, img->preview_fps );
 
 	/* Increment counters */
 	img->still_counter++;
@@ -1389,12 +1406,22 @@ void img_choose_slideshow_filename(GtkWidget *widget, img_window_struct *img)
 	GtkFileChooserAction action = 0;
 	gint response;
 	gchar *filename = NULL;
+    GtkFileFilter *project_filter, *all_files_filter;
 
 	/* Determine the mode of the chooser. */
-	if (widget == img->open_menu || widget == img->open_button)
+	if (widget == img->open_menu || widget == img->open_button || widget == img->import_project_menu)
 		action = GTK_FILE_CHOOSER_ACTION_OPEN;
 	else if (widget == img->save_as_menu || widget == img->save_menu || widget == img->save_button)
 		action = GTK_FILE_CHOOSER_ACTION_SAVE;
+    
+    /* close old slideshow if we import */
+    if (widget == img->open_menu || widget == img->open_button)
+    {
+        if (img->project_is_modified)
+            if (GTK_RESPONSE_OK != img_ask_user_confirmation(img, _("You didn't save your slideshow yet. Are you sure you want to close it?")))
+                return;
+        img_close_slideshow(widget, img);
+    }
 
 	/* If user wants to save empty slideshow, simply abort */
 	if( img->slides_nr == 0 && action == GTK_FILE_CHOOSER_ACTION_SAVE  )
@@ -1411,6 +1438,25 @@ void img_choose_slideshow_filename(GtkWidget *widget, img_window_struct *img)
 					action == GTK_FILE_CHOOSER_ACTION_OPEN ?  GTK_STOCK_OPEN : GTK_STOCK_SAVE,
 					GTK_RESPONSE_ACCEPT,NULL);
 
+        /* Filter .img files */
+        project_filter = gtk_file_filter_new ();
+        gtk_file_filter_set_name(project_filter, _("Imagination projects"));
+        gtk_file_filter_add_pattern(project_filter, "*.img");
+        gtk_file_chooser_add_filter(GTK_FILE_CHOOSER(fc), project_filter);
+
+        /* All files filter */
+        all_files_filter = gtk_file_filter_new ();
+        gtk_file_filter_set_name(all_files_filter, _("All files"));
+        gtk_file_filter_add_pattern(all_files_filter, "*");
+        gtk_file_chooser_add_filter(GTK_FILE_CHOOSER(fc), all_files_filter);
+
+        if (widget == img->save_as_menu || (widget == img->save_menu && img->project_filename == NULL))
+            gtk_file_chooser_set_current_name(GTK_FILE_CHOOSER (fc), "unknown.img");
+        
+        if (img->project_current_dir)
+            gtk_file_chooser_set_current_folder(GTK_FILE_CHOOSER(fc),img->project_current_dir);
+
+
 		gtk_file_chooser_set_do_overwrite_confirmation(GTK_FILE_CHOOSER (fc),TRUE);
 		response = gtk_dialog_run (GTK_DIALOG (fc));
 		if (response == GTK_RESPONSE_ACCEPT)
@@ -1421,6 +1467,10 @@ void img_choose_slideshow_filename(GtkWidget *widget, img_window_struct *img)
 				gtk_widget_destroy(fc);
 				return;
 			}
+			if (img->project_current_dir)
+                g_free(img->project_current_dir);
+            img->project_current_dir = gtk_file_chooser_get_current_folder(GTK_FILE_CHOOSER(fc));
+
 		}
 		else if (response == GTK_RESPONSE_CANCEL || GTK_RESPONSE_DELETE_EVENT)
 		{
@@ -1443,11 +1493,12 @@ void img_choose_slideshow_filename(GtkWidget *widget, img_window_struct *img)
 
 void img_close_slideshow(GtkWidget *widget, img_window_struct *img)
 {
-	if (img->project_is_modified)
-	{
-		if (GTK_RESPONSE_OK != img_ask_user_confirmation(img, _("You didn't save your slideshow yet. Are you sure you want to close it?")))
-			return;
-	}
+    /* When called from close_menu, ask for confirmation */
+    if (img->project_is_modified && widget == img->close_menu)
+    {
+        if (GTK_RESPONSE_OK != img_ask_user_confirmation(img, _("You didn't save your slideshow yet. Are you sure you want to close it?")))
+            return;
+    }
 	img->project_is_modified = FALSE;
 	img_free_allocated_memory(img);
 	img_set_window_title(img,NULL);
@@ -1456,9 +1507,6 @@ void img_close_slideshow(GtkWidget *widget, img_window_struct *img)
 		cairo_surface_destroy( img->current_image );
 	img->current_image = NULL;
 	gtk_widget_queue_draw( img->image_area );
-	gtk_widget_set_sensitive(img->random_button, FALSE);
-	gtk_widget_set_sensitive(img->transition_type, FALSE);
-	gtk_widget_set_sensitive(img->duration, FALSE);
 	gtk_label_set_text(GTK_LABEL (img->total_time_data),"");
 
 	/* Reset slideshow properties */
@@ -1469,13 +1517,10 @@ void img_close_slideshow(GtkWidget *widget, img_window_struct *img)
 	img->final_transition.speed = NORMAL;
 	img->final_transition.render = NULL;
 
-	/* Disable ken burns controls */
-	img_ken_burns_update_sensitivity( img, FALSE, 0 );
+	/* Disable the video tab */
+    img_disable_videotab (img);
 
-	/* Disable subtitle controls */
-	img_subtitle_update_sensitivity( img, 0 );
-	
-	gtk_entry_set_text(GTK_ENTRY(img->slide_number_entry), "");
+    gtk_entry_set_text(GTK_ENTRY(img->slide_number_entry), "");
 }
 
 void img_move_audio_up( GtkButton *button, img_window_struct *img )
@@ -1663,6 +1708,30 @@ img_zoom_reset( GtkWidget         *item,
 		img_overview_change_zoom( 0, TRUE, img );
 }
 
+void
+img_zoom_fit( GtkWidget         *item,
+              img_window_struct *img )
+{
+    gdouble step, level1, level2;
+    
+    if( img->mode == 0 )
+    {
+        /* we want to fit the frame into prev_root. Frame = video + 4 px */
+        level1 = (float)img->prev_root->allocation.width / (img->video_size[0] + 4);
+        level2 = (float)img->prev_root->allocation.height / (img->video_size[1] + 4);
+        if (level1 < level2)
+            /* step is relative to zoom level 1 */
+            step = level1 - 1;
+        else
+            step = level2 - 1;
+
+        img_image_area_change_zoom( 0, TRUE, img );
+        img_image_area_change_zoom( step, FALSE, img );
+    }
+    else
+        img_overview_change_zoom( 0, TRUE, img );
+}
+
 /*
  * img_image_area_change_zoom:
  * @step: amount of zoom to be changed
@@ -1889,6 +1958,8 @@ img_update_subtitles_widgets( img_window_struct *img )
 									 img_text_font_set, img );
 	g_signal_handlers_block_by_func( img->sub_color,
 									 img_font_color_changed, img );
+    g_signal_handlers_block_by_func( img->sub_bgcolor,
+                                     img_font_bgcolor_changed, img );
 	g_signal_handlers_block_by_func( img->sub_anim,
 									 img_text_anim_set, img );
 	g_signal_handlers_block_by_func( img->sub_anim_duration,
@@ -1917,6 +1988,15 @@ img_update_subtitles_widgets( img_window_struct *img )
 	gtk_color_button_set_alpha( GTK_COLOR_BUTTON( img->sub_color ),
 								(gint)(f_colors[3] * 0xffff ) );
 
+    /* Update background color button */
+    f_colors = img->current_slide->font_bgcolor;
+    color.red   = (gint)( f_colors[0] * 0xffff );
+    color.green = (gint)( f_colors[1] * 0xffff );
+    color.blue  = (gint)( f_colors[2] * 0xffff );
+    gtk_color_button_set_color( GTK_COLOR_BUTTON( img->sub_bgcolor ), &color ); 
+    gtk_color_button_set_alpha( GTK_COLOR_BUTTON( img->sub_bgcolor ),
+                                (gint)(f_colors[3] * 0xffff ) );
+
 	/* Update animation */
 	gtk_combo_box_set_active( GTK_COMBO_BOX( img->sub_anim ),
 							  img->current_slide->anim_id );
@@ -1940,6 +2020,8 @@ img_update_subtitles_widgets( img_window_struct *img )
 									   img_text_font_set, img );
 	g_signal_handlers_unblock_by_func( img->sub_color,
 									   img_font_color_changed, img );
+    g_signal_handlers_unblock_by_func( img->sub_bgcolor,
+                                       img_font_bgcolor_changed, img );
 	g_signal_handlers_unblock_by_func( img->sub_anim,
 									   img_text_anim_set, img );
 	g_signal_handlers_unblock_by_func( img->sub_anim_duration,
@@ -2070,7 +2152,7 @@ void img_clipboard_get (GtkClipboard *clipboard, GtkSelectionData *selection_dat
 
 void img_clipboard_clear (GtkClipboard *clipboard, img_window_struct *img)
 {
-	g_print ("I'm here\n");
+	img_message (img, FALSE, "I'm here\n");
 	//gtk_clipboard_clear(clipboard);
 }
 
@@ -2110,7 +2192,7 @@ img_add_empty_slide( GtkMenuItem       *item,
 	gint       i, w, h, pos;
 
 	dialog = gtk_dialog_new_with_buttons(
-					_("Create new slide"),
+					_("Create empty slide"),
 					GTK_WINDOW( img->imagination_window ),
 					GTK_DIALOG_MODAL,
 					GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
@@ -2542,6 +2624,7 @@ img_save_window_settings( img_window_struct *img )
 	g_key_file_set_double(  kf, group, "zoom_o",  img->overview_zoom );
 	g_key_file_set_boolean( kf, group, "quality", img->low_quality );
 	g_key_file_set_boolean( kf, group, "max",     max );
+	g_key_file_set_integer( kf, group, "preview", img->preview_fps );
 
 	rc_path = g_build_filename( g_get_home_dir(), ".config",
 								"imagination", NULL );
@@ -2585,6 +2668,11 @@ img_load_window_settings( img_window_struct *img )
 	img->low_quality     = g_key_file_get_boolean( kf, group, "quality", NULL );
 	max                  = g_key_file_get_boolean( kf, group, "max",     NULL );
 
+	/* New addition to environment settings */
+	img->preview_fps     = g_key_file_get_integer( kf, group, "preview", NULL );
+	if( ! img->preview_fps )
+		img->preview_fps = PREVIEW_FPS_DEFAULT;
+
 	g_key_file_free( kf );
 
 	/* Update mode */
@@ -2616,6 +2704,7 @@ img_set_window_default_settings( img_window_struct *img )
 	img->image_area_zoom = 1.0;
 	img->overview_zoom = 1.0;
 	img->low_quality = TRUE;
+	img->preview_fps = PREVIEW_FPS_DEFAULT;
 
 	/* Update mode */
 	img->mode = - 1;
@@ -2676,3 +2765,19 @@ img_rotate_slide( slide_struct   *slide,
 	slide->angle = angle;
 }
 
+void
+img_notebook_switch_page (GtkNotebook       *notebook,
+                          GtkNotebookPage   *page,
+                          guint              page_num,
+                          img_window_struct *img)
+{
+    /* When message page is viewed, set it back to black */
+    if (page_num == img->message_page)
+    {
+        PangoAttrList *   pango_list = pango_attr_list_new();
+        PangoAttribute *  pango_attr = pango_attr_weight_new (PANGO_WEIGHT_NORMAL);
+        pango_attr_list_insert(pango_list, pango_attr);
+        gtk_label_set_attributes(GTK_LABEL(img->message_label), pango_list);
+        pango_attr_list_unref (pango_list);
+    }
+}
\ No newline at end of file
