@@ -81,6 +81,10 @@ void
 img_zoom_reset( GtkWidget         *item,
 				img_window_struct *img );
 
+void
+img_zoom_fit( GtkWidget         *item,
+              img_window_struct *img );
+
 void
 img_quality_toggled( GtkCheckMenuItem  *item,
 					 img_window_struct *img );
@@ -139,4 +143,11 @@ void
 img_rotate_slide( slide_struct   *slide,
 				  ImgAngle        angle,
 				  GtkProgressBar *progress );
+
+void
+img_notebook_switch_page (GtkNotebook       *notebook,
+                          GtkNotebookPage   *page,
+                          guint              page_num,
+                          img_window_struct *img);
+
 #endif
