@@ -1,6 +1,7 @@
 /*
 ** Copyright (c) 2009 Giuseppe Torelli <colossus73@gmail.com>
 ** Copyright (C) 2009 Tadej Borovšak   <tadeboro@gmail.com>
+** Copyright (c) 2011 Robert Chéramy   <robert@cheramy.net>
 **  
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -25,9 +26,6 @@
 #include <fcntl.h>
 #include <glib/gstdio.h>
 
-static void
-img_export_flv_changed( GtkComboBox   *, GtkWidget * );
-
 static GtkWidget *
 img_create_export_dialog( img_window_struct  *img,
 						  const gchar        *title,
@@ -62,74 +60,12 @@ img_export_frame_to_ppm( cairo_surface_t *surface,
 						 gint             file_desc );
 
 static void
-img_exporter_vob( img_window_struct *img );
-static void
-img_exporter_ogg( img_window_struct *img );
+img_exporter_ogv( img_window_struct *img );
 static void
 img_exporter_flv( img_window_struct *img );
 static void
 img_exporter_3gp( img_window_struct *img );
 
-
-/*
- * img_get_exporters:
- * @exporters: location to put list of available exporters
- *
- * This function is here to simplify accessing all available exporters.
- *
- * Any newly added exporters should be listed in array returned by this function
- * or Imagination WILL NOT create menu entries for them.
- *
- * List that is placed in exporters parameter should be considered read-only and
- * freed after usage with img_free_exporters_list.
- *
- * Return value: Size of list in exporters.
- */
-gint
-img_get_exporters_list( Exporter **exporters )
-{
-	Exporter *list;             /* List of all exporters */
-	gint      no_exporters = 4; /* Total number of exporters */
-	gint      i = 0;
-	
-	list = g_slice_alloc( sizeof( Exporter ) * no_exporters );
-
-	/* Populate list with data */
-	list[i].description = g_strdup( "VOB (DVD video)" );
-	list[i++].func = G_CALLBACK( img_exporter_vob );
-	list[i].description = g_strdup( "OGV (Theora/Vorbis)" );
-	list[i++].func = G_CALLBACK( img_exporter_ogg );
-	list[i].description = g_strdup( "FLV (Flash video)" );
-	list[i++].func = G_CALLBACK( img_exporter_flv );
-	list[i].description = g_strdup( "3GP (Mobile Phones)" );
-	list[i++].func = G_CALLBACK( img_exporter_3gp );
-
-	*exporters = list;
-
-	return( no_exporters );
-}
-
-/*
- * img_free_exporters_list:
- * @no_exporters: number of exporters in exporters list
- * @exporters: array of Exporter structs
- *
- * This function takes care of freeing any memory allocated by
- * img_get_exporters_list function.
- */
-void
-img_free_exporters_list( gint      no_exporters,
-						 Exporter *exporters )
-{
-	register gint i;
-
-	for( i = 0; i < no_exporters; i++ )
-		g_free( exporters[i].description );
-
-	g_slice_free1( sizeof( Exporter ) * no_exporters, exporters );
-}
-
-
 /*
  * img_create_export_dialog:
  * @title: title to display with dialog
@@ -225,7 +161,7 @@ img_create_export_dialog( img_window_struct  *img,
 	hbox_slideshow_name = gtk_hbox_new (TRUE, 0);
 	gtk_box_pack_start (GTK_BOX (vbox_frame1), hbox_slideshow_name, TRUE, TRUE, 0);
 
-	label = gtk_label_new( _("Filename of the slideshow:") );
+	label = gtk_label_new( _("Filename:") );
 	gtk_box_pack_start( GTK_BOX( hbox_slideshow_name ), label, FALSE, TRUE, 0 );
 	gtk_misc_set_alignment(GTK_MISC(label), 0, 0.5);
 
@@ -707,14 +643,15 @@ img_run_encoder( img_window_struct *img )
 	gboolean    ret;
 
 	g_shell_parse_argv( img->export_cmd_line, &argc, &argv, NULL);
-	g_print( "%s\n", img->export_cmd_line);
+	img_message(img, FALSE, "Running %s\n", img->export_cmd_line);
 
 	ret = g_spawn_async_with_pipes( NULL, argv, NULL,
-									G_SPAWN_SEARCH_PATH |
-									G_SPAWN_STDOUT_TO_DEV_NULL |
-									G_SPAWN_STDERR_TO_DEV_NULL,
+									G_SPAWN_SEARCH_PATH,
 									NULL, NULL, &img->ffmpeg_export,
-									&img->file_desc, NULL, NULL, &error );
+									&img->file_desc,
+                                    NULL,               /* print to standard_output */
+                                    NULL,               /* print to standard_error */
+                                    &error );
 	if( ! ret )
 	{
 		message = gtk_message_dialog_new( GTK_WINDOW( img->imagination_window ),
@@ -728,6 +665,7 @@ img_run_encoder( img_window_struct *img )
 		gtk_widget_destroy( message );
 		g_error_free( error );
 	}
+
 	g_strfreev( argv );
 
 	return( ret );
@@ -1092,6 +1030,7 @@ img_render_still_frame( img_window_struct *img,
 							 img->work_slide->subtitle,
 							 img->work_slide->font_desc,
 							 img->work_slide->font_color,
+                             img->work_slide->font_bgcolor,
 							 img->work_slide->anim,
 							 progress );
 	}
@@ -1121,7 +1060,7 @@ img_export_frame_to_ppm( cairo_surface_t *surface,
 	 * formats. */
 	if( ! format == CAIRO_FORMAT_ARGB32 && ! format == CAIRO_FORMAT_RGB24 )
 	{
-		g_print( "Unsupported cairo surface format!\n" );
+		g_print("Unsupported cairo surface format!\n" );
 		return;
 	}
 
@@ -1216,13 +1155,13 @@ img_export_frame_to_ppm( cairo_surface_t *surface,
  * placeholder named <#AUDIO#>, which will be in next stage replaced by real
  * path to newly produced audio file (at this stage, we don't have any).
  * ************************************************************************* */
-static void
-img_exporter_vob( img_window_struct *img )
+
+void img_exporter_vob( img_window_struct *img )
 {
 	gchar          *cmd_line;
 	gchar          *format;
 	const gchar    *filename;
-	gchar          *aspect_ratio;
+	gchar          *aspect_ratio, *aspect_ratio_cmd;
 	GtkWidget      *dialog;
 	GtkEntry       *entry;
 	GtkWidget      *vbox;
@@ -1232,11 +1171,16 @@ img_exporter_vob( img_window_struct *img )
 	GtkWidget *label;
 	GtkWidget *hbox;
 	GtkWidget *radio1, *radio2;
+    
+    /* ffmpeg test */
+    gchar *ffmpeg_test_result;
+    gchar **argv;
+    gint    argc;
 
 	/* This function call should be the first thing exporter does, since this
 	 * function will take some preventive measures and also switches mode into
 	 * preview if needed. */
-	dialog = img_create_export_dialog( img, _("VOB export"),
+	dialog = img_create_export_dialog( img, _("VOB (DVD video)"),
 									   GTK_WINDOW( img->imagination_window ),
 									   &entry, &vbox );
 
@@ -1274,20 +1218,52 @@ img_exporter_vob( img_window_struct *img )
 
 	/* User is serious, so we better prepare ffmepg command line;) */
 	img->export_is_running = 1;
-	format = img->video_size[1] == 576 ? "pal" : "ntsc";
-	img->export_fps = 30;
+    if (img->video_size[1] == 576)
+    {
+        format = "pal";
+        img->export_fps = 25;
+    }
+    else
+    {
+        format = "ntsc";
+        img->export_fps = 30;
+    }
 	filename = gtk_entry_get_text( entry );
 	if( gtk_toggle_button_get_active( GTK_TOGGLE_BUTTON( radio1 ) ) )
 		aspect_ratio = "4:3";
 	else
 		aspect_ratio = "16:9";
 
-	cmd_line = g_strdup_printf( "ffmpeg -f image2pipe -vcodec ppm -r %.02f "
-								"-aspect %s -s %dx%d -i pipe: <#AUDIO#> -y "
-								"-bf 2 -target %s-dvd \"%s.vob\"",
-								img->export_fps, aspect_ratio,
-								img->video_size[0], img->video_size[1],
-								format, filename );
+
+    /* Check if ffmpeg is compiled with avfilter setdar */
+    img_message(img, FALSE, "Testing ffmpeg abilities with \"ffmpeg -filters\" ... ");
+
+    g_shell_parse_argv("ffmpeg -filters", &argc, &argv, NULL);
+    g_spawn_sync(NULL, argv, NULL,
+                 G_SPAWN_STDERR_TO_DEV_NULL|G_SPAWN_SEARCH_PATH,
+                 NULL, NULL,
+                 &ffmpeg_test_result, NULL,
+                 NULL, NULL);
+    if (NULL != ffmpeg_test_result && NULL != g_strrstr(ffmpeg_test_result, "setdar"))
+    {
+        img_message(img, FALSE, "setdar found!\n");
+        aspect_ratio_cmd = "-vf setdar=";
+    }
+    else
+    {
+        img_message(img, FALSE, "setdar not found!\n");
+        aspect_ratio_cmd = "-aspect ";
+
+    }
+    g_strfreev( argv );
+
+	cmd_line = g_strdup_printf( "ffmpeg -f image2pipe -vcodec ppm -r %.0f "
+								"-i pipe: <#AUDIO#> -y "
+								"-bf 2 -target %s-dvd -s %dx%d %s%s \"%s\"",
+								img->export_fps,
+								format,
+                                img->video_size[0], img->video_size[1],
+                                aspect_ratio_cmd, aspect_ratio, filename );
 	img->export_cmd_line = cmd_line;
 
 	/* Initiate stage 2 of export - audio processing */
@@ -1297,7 +1273,7 @@ img_exporter_vob( img_window_struct *img )
 }
 
 static void
-img_exporter_ogg( img_window_struct *img )
+img_exporter_ogv( img_window_struct *img )
 {
 	gchar          *cmd_line;
 	const gchar    *filename;
@@ -1307,19 +1283,20 @@ img_exporter_ogg( img_window_struct *img )
 	GtkWidget      *vbox;
 
 	/* Additional options - OGG  only */
-	GtkWidget *frame;
-	GtkWidget *label;
-	GtkWidget *hbox;
+	GtkWidget *frame, *alignment, *label;
+	GtkWidget *hbox, *vbox_normal;
 	GtkWidget *radio1, *radio2;
+	GtkWidget *video_size_combo;
 	GtkWidget *radios[3];
-	gint       i;
+	gint	  i, width, height;
+
 	/* These values have been contributed by Jean-Pierre Redonnet.
 	 * Thanks. */
 	gint       qualities[] = { 512, 1024, 2048 };
 
 	/* This function call should be the first thing exporter does, since this
 	 * function will take some preventive measures. */
-	dialog = img_create_export_dialog( img, _("OGG export"),
+	dialog = img_create_export_dialog( img, _("OGV (Theora/Vorbis)"),
 									   GTK_WINDOW( img->imagination_window ),
 									   &entry, &vbox );
 
@@ -1328,24 +1305,68 @@ img_exporter_ogg( img_window_struct *img )
 		return;
 
 	/* Add any export format specific GUI elements here */
-	frame = gtk_frame_new( NULL );
-	gtk_box_pack_start( GTK_BOX( vbox ), frame, FALSE, FALSE, 0 );
+	hbox = gtk_hbox_new( TRUE, 10 );
+	gtk_box_pack_start( GTK_BOX( vbox ), hbox, FALSE, FALSE, 0 );
 
-	label = gtk_label_new( _("<b>Television Format</b>") );
+	/* Aspect Ratio */
+	frame = gtk_frame_new( NULL );
+	gtk_box_pack_start( GTK_BOX( hbox ), frame, TRUE, TRUE, 0 );
+
+	label = gtk_label_new( _("<b>Aspect Ratio</b>") );
 	gtk_label_set_use_markup( GTK_LABEL( label ), TRUE );
 	gtk_frame_set_label_widget( GTK_FRAME( frame ), label );
 
-	hbox = gtk_hbox_new( TRUE, 5 );
-	gtk_container_add( GTK_CONTAINER( frame ), hbox );
+	alignment = gtk_alignment_new(0.5, 0.5, 0.5, 0.5);
+	gtk_container_add (GTK_CONTAINER (frame), alignment);
+	gtk_alignment_set_padding (GTK_ALIGNMENT (alignment), 0, 0, 5, 5);
+
+	vbox_normal = gtk_vbox_new( FALSE, 0 );
+	gtk_container_add( GTK_CONTAINER( alignment ), vbox_normal );
 
 	radio1 = gtk_radio_button_new_with_mnemonic( NULL, _("Normal 4:3") );
 	gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON( radio1 ), TRUE );
-	gtk_box_pack_start( GTK_BOX( hbox ), radio1, FALSE, FALSE, 0 );
+	gtk_box_pack_start( GTK_BOX( vbox_normal ), radio1, FALSE, FALSE, 0 );
 
-	radio2 = gtk_radio_button_new_with_mnemonic_from_widget(
-				GTK_RADIO_BUTTON( radio1 ), _("Widescreen 16:9") );
-	gtk_box_pack_start( GTK_BOX( hbox ), radio2, FALSE, FALSE, 0 );
-	
+	radio2 = gtk_radio_button_new_with_mnemonic_from_widget(GTK_RADIO_BUTTON( radio1 ), _("Widescreen 16:9") );
+	gtk_box_pack_start( GTK_BOX( vbox_normal ), radio2, FALSE, FALSE, 0 );
+
+	/* Video Size */
+	frame = gtk_frame_new( NULL );
+	gtk_box_pack_start( GTK_BOX( hbox ), frame, TRUE, TRUE, 0 );
+
+	label = gtk_label_new( _("<b>Video Size</b>") );
+	gtk_label_set_use_markup( GTK_LABEL( label ), TRUE );
+	gtk_frame_set_label_widget( GTK_FRAME( frame ), label );
+
+	alignment = gtk_alignment_new(0.5, 0.5, 0.5, 0.5);
+	gtk_container_add (GTK_CONTAINER (frame), alignment);
+	gtk_alignment_set_padding (GTK_ALIGNMENT (alignment), 0, 0, 5, 5);
+
+	vbox_normal = gtk_vbox_new( FALSE, 0 );
+	gtk_container_add (GTK_CONTAINER (alignment), vbox_normal);
+
+	video_size_combo = _gtk_combo_box_new_text(FALSE);
+	gtk_box_pack_start( GTK_BOX( vbox_normal ), video_size_combo, FALSE, FALSE, 0 );
+	{
+		GtkTreeIter   iter;
+		GtkListStore *store = GTK_LIST_STORE( gtk_combo_box_get_model(GTK_COMBO_BOX( video_size_combo ) ) );
+
+		gtk_list_store_append( store, &iter );
+		gtk_list_store_set( store, &iter, 0, "320 x 240", -1 );
+		gtk_list_store_append( store, &iter );
+		gtk_list_store_set( store, &iter, 0, "352 x 288", -1 );
+		gtk_list_store_append( store, &iter );
+		gtk_list_store_set( store, &iter, 0, "400 x 300", -1 );
+		gtk_list_store_append( store, &iter );
+		gtk_list_store_set( store, &iter, 0, "512 x 384", -1 );
+		gtk_list_store_append( store, &iter );
+		gtk_list_store_set( store, &iter, 0, "640 x 480", -1 );
+		gtk_list_store_append( store, &iter );
+		gtk_list_store_set( store, &iter, 0, "704 x 576", -1 );
+	}
+	gtk_combo_box_set_active( GTK_COMBO_BOX( video_size_combo ), 0 );
+
+	/* Video Quality */
 	frame = gtk_frame_new( NULL );
 	gtk_box_pack_start( GTK_BOX( vbox ), frame, FALSE, FALSE, 0 );
 
@@ -1383,6 +1404,39 @@ img_exporter_ogg( img_window_struct *img )
 	filename = gtk_entry_get_text( entry );
 
 	/* Any additional calculation can be placed here. */
+	switch(gtk_combo_box_get_active(GTK_COMBO_BOX(video_size_combo)) )
+	{
+		case 0:
+		width  = 320;
+		height = 240;
+		break;
+		
+		case 1:
+		width  = 352;
+		height = 288;
+		break;
+
+		case 2:
+		width  = 400;
+		height = 300;
+		break;
+
+		case 3:
+		width  = 512;
+		height = 384;
+		break;
+
+		case 4:
+		width  = 640;
+		height = 480;
+		break;
+
+		case 5:
+		width  = 704;
+		height = 576;
+		break;
+	}
+
 	if( gtk_toggle_button_get_active( GTK_TOGGLE_BUTTON( radio1 ) ) )
 		aspect_ratio = "4:3";
 	else
@@ -1394,12 +1448,11 @@ img_exporter_ogg( img_window_struct *img )
 			break;
 	}
 
-	cmd_line = g_strdup_printf( "ffmpeg -f image2pipe -vcodec ppm -r %.02f "
-								"-aspect %s -s %dx%d -i pipe: <#AUDIO#> "
+	cmd_line = g_strdup_printf( "ffmpeg -f image2pipe -vcodec ppm -r %.0f "
+								"-i pipe: <#AUDIO#> -f ogg -aspect %s -s %dx%d "
 								"-vcodec libtheora -b %dk -acodec libvorbis "
-								"-f ogg -y \"%s.ogv\"",
-								img->export_fps, aspect_ratio,
-								img->video_size[0], img->video_size[1],
+								"-y \"%s\"",
+								img->export_fps, aspect_ratio, width, height,
 								qualities[i], filename );
 	img->export_cmd_line = cmd_line;
 
@@ -1421,19 +1474,16 @@ img_exporter_flv( img_window_struct *img )
 	/* Additional options - FLV  only */
 	GtkWidget *frame;
 	GtkWidget *label;
-	GtkWidget *hbox, *vbox_normal, *vbox_wide;
+	GtkWidget *hbox, *vbox_normal, *alignment;
 	GtkWidget *radio1, *radio2;
-	GtkWidget *normal_combo, *wide_combo;
+	GtkWidget *video_size_combo;
 	GtkWidget *radios[3];
 	gint       i, width, height;
-
-	/* These values have been contributed by Jean-Pierre Redonnet.
-	 * Thanks. */
-	gint       qualities[] = { 192, 384, 768 };
+	gint       qualities[] = { 384, 768, 1536 };
 
 	/* This function call should be the first thing exporter does, since this
 	 * function will take some preventive measures. */
-	dialog = img_create_export_dialog( img, _("FLV export"),
+	dialog = img_create_export_dialog( img, _("FLV (Flash video)"),
 									   GTK_WINDOW( img->imagination_window ),
 									   &entry, &vbox );
 
@@ -1442,65 +1492,64 @@ img_exporter_flv( img_window_struct *img )
 		return;
 
 	/* Add any export format specific GUI elements here */
+	hbox = gtk_hbox_new( TRUE, 10 );
+	gtk_box_pack_start( GTK_BOX( vbox ), hbox, FALSE, FALSE, 0 );
+
+	/* Aspect Ratio */
 	frame = gtk_frame_new( NULL );
-	gtk_box_pack_start( GTK_BOX( vbox ), frame, FALSE, FALSE, 0 );
+	gtk_box_pack_start( GTK_BOX( hbox ), frame, TRUE, TRUE, 0 );
+
+	label = gtk_label_new( _("<b>Aspect Ratio</b>") );
+	gtk_label_set_use_markup( GTK_LABEL( label ), TRUE );
+	gtk_frame_set_label_widget( GTK_FRAME( frame ), label );
+
+	alignment = gtk_alignment_new(0.5, 0.5, 0.5, 0.5);
+	gtk_container_add (GTK_CONTAINER (frame), alignment);
+	gtk_alignment_set_padding (GTK_ALIGNMENT (alignment), 0, 0, 5, 5);
+
+	vbox_normal = gtk_vbox_new( FALSE, 0 );
+	gtk_container_add( GTK_CONTAINER( alignment ), vbox_normal );
+
+	radio1 = gtk_radio_button_new_with_mnemonic( NULL, _("Normal 4:3") );
+	gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON( radio1 ), TRUE );
+	gtk_box_pack_start( GTK_BOX( vbox_normal ), radio1, FALSE, FALSE, 0 );
+
+	radio2 = gtk_radio_button_new_with_mnemonic_from_widget(GTK_RADIO_BUTTON( radio1 ), _("Widescreen 16:9") );
+	gtk_box_pack_start( GTK_BOX( vbox_normal ), radio2, FALSE, FALSE, 0 );
+
+	/* Video Size */
+	frame = gtk_frame_new( NULL );
+	gtk_box_pack_start( GTK_BOX( hbox ), frame, TRUE, TRUE, 0 );
 
 	label = gtk_label_new( _("<b>Video Size</b>") );
 	gtk_label_set_use_markup( GTK_LABEL( label ), TRUE );
 	gtk_frame_set_label_widget( GTK_FRAME( frame ), label );
 
-	hbox = gtk_hbox_new( TRUE, 5 );
-	gtk_container_add( GTK_CONTAINER( frame ), hbox );
+	alignment = gtk_alignment_new(0.5, 0.5, 0.5, 0.5);
+	gtk_container_add (GTK_CONTAINER (frame), alignment);
+	gtk_alignment_set_padding (GTK_ALIGNMENT (alignment), 0, 0, 5, 5);
 
 	vbox_normal = gtk_vbox_new( FALSE, 0 );
-	gtk_box_pack_start (GTK_BOX(hbox), vbox_normal, FALSE, FALSE, 0 );
-	
-	radio1 = gtk_radio_button_new_with_mnemonic( NULL, _("Normal 4:3") );
-	gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON( radio1 ), TRUE );
-	gtk_box_pack_start( GTK_BOX( vbox_normal ), radio1, FALSE, FALSE, 0 );
+	gtk_container_add (GTK_CONTAINER (alignment), vbox_normal);
 
-	normal_combo = _gtk_combo_box_new_text(FALSE);
-	gtk_box_pack_start( GTK_BOX( vbox_normal ), normal_combo, FALSE, FALSE, 0 );
+	video_size_combo = _gtk_combo_box_new_text(FALSE);
+	gtk_box_pack_start( GTK_BOX( vbox_normal ), video_size_combo, FALSE, FALSE, 0 );
 	{
 		GtkTreeIter   iter;
-		GtkListStore *store = GTK_LIST_STORE( gtk_combo_box_get_model(GTK_COMBO_BOX( normal_combo ) ) );
+		GtkListStore *store = GTK_LIST_STORE( gtk_combo_box_get_model(GTK_COMBO_BOX( video_size_combo ) ) );
 
 		gtk_list_store_append( store, &iter );
 		gtk_list_store_set( store, &iter, 0, "320 x 240", -1 );
 		gtk_list_store_append( store, &iter );
+		gtk_list_store_set( store, &iter, 0, "352 x 288", -1 );
+		gtk_list_store_append( store, &iter );
 		gtk_list_store_set( store, &iter, 0, "400 x 300", -1 );
 		gtk_list_store_append( store, &iter );
 		gtk_list_store_set( store, &iter, 0, "512 x 384", -1 );
 		gtk_list_store_append( store, &iter );
-		gtk_list_store_set( store, &iter, 0, "640 x 480", -1 );
-	}
-	gtk_combo_box_set_active( GTK_COMBO_BOX( normal_combo ), 0 );
-
-	vbox_wide = gtk_vbox_new( FALSE, 0 );
-	gtk_box_pack_start (GTK_BOX(hbox), vbox_wide, FALSE, FALSE, 0 );
-
-	radio2 = gtk_radio_button_new_with_mnemonic_from_widget(GTK_RADIO_BUTTON( radio1 ), _("Widescreen 16:9") );
-	gtk_box_pack_start( GTK_BOX( vbox_wide ), radio2, FALSE, FALSE, 0 );
-
-	wide_combo = _gtk_combo_box_new_text(FALSE);
-	gtk_box_pack_start( GTK_BOX( vbox_wide ), wide_combo, FALSE, FALSE, 0 );
-	
-	{
-		GtkTreeIter   iter;
-		GtkListStore *store = GTK_LIST_STORE( gtk_combo_box_get_model(GTK_COMBO_BOX( wide_combo ) ) );
-
-		gtk_list_store_append( store, &iter );
-		gtk_list_store_set( store, &iter, 0, "320 x 180", -1 );
-		gtk_list_store_append( store, &iter );
-		gtk_list_store_set( store, &iter, 0, "400 x 225", -1 );
-		gtk_list_store_append( store, &iter );
-		gtk_list_store_set( store, &iter, 0, "512 x 288", -1 );
-		gtk_list_store_append( store, &iter );
 		gtk_list_store_set( store, &iter, 0, "640 x 360", -1 );
 	}
-	gtk_combo_box_set_active( GTK_COMBO_BOX( wide_combo ), 0 );
-	g_signal_connect( G_OBJECT( normal_combo ), "changed", G_CALLBACK( img_export_flv_changed ), radio1 );
-	g_signal_connect( G_OBJECT( wide_combo ), "changed", G_CALLBACK( img_export_flv_changed ), radio2 );
+	gtk_combo_box_set_active( GTK_COMBO_BOX( video_size_combo ), 0 );
 
 	frame = gtk_frame_new( NULL );
 	gtk_box_pack_start( GTK_BOX( vbox ), frame, FALSE, FALSE, 0 );
@@ -1538,27 +1587,32 @@ img_exporter_flv( img_window_struct *img )
 	img->export_fps = 30;
 	filename = gtk_entry_get_text( entry );
 
-	/* Any additional calculation can be placed here. */
+	/* The -aspect parameter for FLV format seems to be ignored by ffmpeg */
 	if( gtk_toggle_button_get_active( GTK_TOGGLE_BUTTON( radio1 ) ) )
 	{
-		switch(gtk_combo_box_get_active(GTK_COMBO_BOX(normal_combo)) )
+		switch(gtk_combo_box_get_active(GTK_COMBO_BOX(video_size_combo)) )
 		{
 			case 0:
 			width  = 320;
 			height = 240;
 			break;
-
+		
 			case 1:
+			width  = 352;
+			height = 288;
+			break;
+
+			case 2:
 			width  = 400;
 			height = 300;
 			break;
 
-			case 2:
+			case 3:
 			width  = 512;
 			height = 384;
 			break;
 
-			case 3:
+			case 4:
 			width  = 640;
 			height = 480;
 			break;
@@ -1566,24 +1620,29 @@ img_exporter_flv( img_window_struct *img )
 	}
 	else
 	{
-		switch(gtk_combo_box_get_active(GTK_COMBO_BOX(wide_combo)) )
+		switch(gtk_combo_box_get_active(GTK_COMBO_BOX(video_size_combo)) )
 		{
 			case 0:
-			width  = 320;
-			height = 180;
+			width  = 426;
+			height = 240;
 			break;
-
+		
 			case 1:
-			width  = 400;
-			height = 225;
-			break;
-
-			case 2:
 			width  = 512;
 			height = 288;
 			break;
 
+			case 2:
+			width  = 534;
+			height = 300;
+			break;
+
 			case 3:
+			width  = 682;
+			height = 384;
+			break;
+
+			case 4:
 			width  = 640;
 			height = 360;
 			break;
@@ -1596,12 +1655,12 @@ img_exporter_flv( img_window_struct *img )
 			break;
 	}
 
-	cmd_line = g_strdup_printf( "ffmpeg -f image2pipe -vcodec ppm -r %.02f "
-								"-b %dk -s %dx%d -i pipe: <#AUDIO#> -f flv "
-								"-vcodec flv -acodec libmp3lame -ab 56000 "
-								"-ar 22050 -ac 1 -y \"%s.flv\"",
-								img->export_fps, qualities[i],
-								width, height, filename );
+	cmd_line = g_strdup_printf( "ffmpeg -f image2pipe -vcodec ppm -r %.0f "
+								"-i pipe: <#AUDIO#> -f flv -s %dx%d "
+								"-vcodec flv -b %dk -acodec libmp3lame -ab 56000 "
+								"-ar 22050 -ac 1 -y \"%s\"",
+								img->export_fps, width, height,
+								qualities[i], filename );
 	img->export_cmd_line = cmd_line;
 
 	/* Initiate stage 2 of export - audio processing */
@@ -1620,15 +1679,15 @@ img_exporter_3gp( img_window_struct *img )
 	GtkWidget      *vbox;
 
 	/* Additional options - 3GP  only */
-	GtkWidget *frame1, *frame2;
+	GtkWidget *frame1, *alignment;
 	GtkWidget *label;
-	GtkWidget *hbox;
+	GtkWidget *hbox, *vbox_normal;
 	GtkWidget *normal_combo;
 	gint       width, height;
 
 	/* This function call should be the first thing exporter does, since this
 	 * function will take some preventive measures. */
-	dialog = img_create_export_dialog( img, _("3GP export"),
+	dialog = img_create_export_dialog( img, _("3GP (Mobile Phones)"),
 									   GTK_WINDOW( img->imagination_window ),
 									   &entry, &vbox );
 
@@ -1641,14 +1700,21 @@ img_exporter_3gp( img_window_struct *img )
 	gtk_container_add( GTK_CONTAINER( vbox ), hbox );
 	
 	frame1 = gtk_frame_new( NULL );
-	gtk_box_pack_start( GTK_BOX( hbox ), frame1, FALSE, FALSE, 0 );
+	gtk_box_pack_start( GTK_BOX( hbox ), frame1, FALSE, TRUE, 0 );
 
 	label = gtk_label_new( _("<b>Video Size</b>") );
 	gtk_label_set_use_markup( GTK_LABEL( label ), TRUE );
 	gtk_frame_set_label_widget( GTK_FRAME( frame1 ), label );
 
+	alignment = gtk_alignment_new(0, 0, 0.5, 0.5);
+	gtk_container_add (GTK_CONTAINER (frame1), alignment);
+	gtk_alignment_set_padding (GTK_ALIGNMENT (alignment), 5, 5, 5, 5);
+
+	vbox_normal = gtk_vbox_new( FALSE, 0 );
+	gtk_container_add (GTK_CONTAINER (alignment), vbox_normal);
+
 	normal_combo = _gtk_combo_box_new_text(FALSE);
-	gtk_container_add (GTK_CONTAINER (frame1), normal_combo);
+	gtk_box_pack_start( GTK_BOX( vbox_normal ), normal_combo, FALSE, FALSE, 0 );
 	{
 		GtkTreeIter   iter;
 		GtkListStore *store = GTK_LIST_STORE( gtk_combo_box_get_model(GTK_COMBO_BOX( normal_combo ) ) );
@@ -1701,10 +1767,10 @@ img_exporter_3gp( img_window_struct *img )
 		break;
 	}
 
-	cmd_line = g_strdup_printf( "ffmpeg -f image2pipe -vcodec ppm -r %.02f "
+	cmd_line = g_strdup_printf( "ffmpeg -f image2pipe -vcodec ppm -r %.0f "
 								"-i pipe: <#AUDIO#> -f 3gp -s %dx%d "
 								"-vcodec h263 -acodec libfaac -b 192k -ab 32k "
-								"-ar 8000 -ac 1 -y \"%s.3gp\"",
+								"-ar 8000 -ac 1 -y \"%s\"",
 								img->export_fps,
 								width, height, filename );
 	img->export_cmd_line = cmd_line;
@@ -1718,7 +1784,29 @@ img_exporter_3gp( img_window_struct *img )
  * End exporters
  * ************************************************************************* */
 
-static void img_export_flv_changed( GtkComboBox   *combo, GtkWidget *radio )
+void img_choose_exporter(GtkWidget *button, img_window_struct *img)
 {
-	gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON( radio ), TRUE );
+	switch (img->video_format)
+	{
+		default:
+		case 'V':
+		img_exporter_vob(img);
+		break;
+
+		case 'O':
+		img_exporter_ogv(img);
+		break;
+
+		case 'F':
+		img_exporter_flv(img);
+		break;
+
+		case '3':
+		img_exporter_3gp(img);
+		break;
+
+		case 'M':
+		//img_exporter_vob(img);
+		break;
+	}
 }
