@@ -27,7 +27,10 @@
 
 /* Transition preview frame rate. I decided to use 25 fps, which
  * should be handled on time by most machines. */
-#define PREVIEW_FPS 15
+#define PREVIEW_FPS_STEP       5
+#define PREVIEW_FPS_MIN        5
+#define PREVIEW_FPS_NO_PRESETS 6
+#define PREVIEW_FPS_DEFAULT    15
 
 /* The transition speed is defined as a duration in seconds. */
 #define	FAST	1
@@ -103,7 +106,8 @@ typedef void (*TextAnimationFunc)( cairo_t     *cr,
 								   gint         posx,
 								   gint         posy,
 								   gdouble      progress,
-								   gdouble     *font_color );
+								   gdouble     *font_color,
+                                   gdouble     *font_bgcolor );
 
 
 /* ****************************************************************************
@@ -153,6 +157,9 @@ struct _slide_struct
 	gchar    *o_filename; /* Filename of the image that slide represents */
 	gchar    *r_filename; /* o_filename, rotated according to angle */
 	ImgAngle  angle;      /* Angle of rotated image */
+    gboolean  load_ok;    /* handle loading problems (file not found, format unknown...) */
+    gchar    *original_filename; /* Filename as loaded from the project file */
+
 
 	/* Fields that are filled if we create slide in memory */
 	gint    gradient;         /* Gradient type */
@@ -176,14 +183,15 @@ struct _slide_struct
 	gint   cur_point; /* Currently active stop point */
 
 	/* Subtitle variables */
-	gchar                *subtitle;      /* Subtitle text */
-	TextAnimationFunc     anim;          /* Animation functions */
-	gint                  anim_id;       /* Animation id */
-	gint                  anim_duration; /* Duration of animation */
-	ImgSubPos             position;      /* Final position of subtitle */
-	ImgRelPlacing         placing;       /* Relative placing */
-	PangoFontDescription *font_desc;     /* Font description */
-	gdouble               font_color[4]; /* Font color (RGBA format) */
+	gchar                *subtitle;        /* Subtitle text */
+	TextAnimationFunc     anim;            /* Animation functions */
+	gint                  anim_id;         /* Animation id */
+	gint                  anim_duration;   /* Duration of animation */
+	ImgSubPos             position;        /* Final position of subtitle */
+	ImgRelPlacing         placing;         /* Relative placing */
+	PangoFontDescription *font_desc;       /* Font description */
+	gdouble               font_color[4];   /* Font color (RGBA format) */
+    gdouble               font_bgcolor[4]; /* Font background color (RGBA format) */
 };
 
 typedef struct _img_window_struct img_window_struct;
@@ -193,6 +201,8 @@ struct _img_window_struct
 	GtkWidget	*imagination_window;	// Main window
 	GtkAccelGroup *accel_group;
 	GtkWidget	*open_menu;
+    GtkWidget   *close_menu;
+    GtkWidget   *import_project_menu;
 	GtkWidget	*save_menu;
 	GtkWidget	*save_as_menu;
 	GtkWidget	*open_button;
@@ -220,6 +230,8 @@ struct _img_window_struct
   	GtkWidget	*statusbar;
   	GtkWidget	*progress_bar;
   	GtkWidget	*image_area;
+  	GtkWidget	*video_format_combo;
+  	GtkWidget	*video_size_combo;
   	guint		context_id;
   	GtkListStore *thumbnail_model;
   	gchar		*current_dir;
@@ -251,6 +263,7 @@ struct _img_window_struct
 	GtkWidget *sub_textview;      /* Text view */
 	GtkWidget *sub_font;          /* Font button */
 	GtkWidget *sub_color;         /* Color selector button */
+    GtkWidget *sub_bgcolor;       /* Background Color selector button */
 	GtkWidget *sub_anim;          /* Animation combo box */
 	GtkWidget *sub_anim_duration; /* Animation duration spin button */
 	GtkWidget *sub_placing;       /* Placing combo box */
@@ -281,8 +294,10 @@ struct _img_window_struct
 
 	/* Project related variables */
 	gchar       *project_filename;		// project name for saving
+	gchar       *project_current_dir;
 	gboolean	distort_images;
 	gboolean	project_is_modified;
+	gchar		video_format;
 	gint        video_size[2];
 	gdouble     video_ratio;
 	gdouble     background_color[3];
@@ -377,10 +392,16 @@ struct _img_window_struct
 	GtkListStore *music_file_liststore;
 	GtkWidget	*music_time_data;
 	GPid		play_child_pid;
+    
+    /* Messages related stuf */
+    GtkTextBuffer  *message_buffer;
+    GtkWidget      *message_label;
+    gint            message_page;
 
 	/* Application related stuff */
 	gdouble  image_area_zoom; /* Zoom to be applied to image area */
 	gdouble  overview_zoom;   /* Zoom to be applied in overview mode */
+	gint     preview_fps;     /* Preview frame rate */
 	gboolean low_quality;     /* Preview quality:
 								  TRUE  - preview in low-res
 								  FALSE - preview in hi-res */
