@@ -27,5 +27,6 @@
 #include "callbacks.h"
 
 void img_new_slideshow_settings_dialog(img_window_struct *, gboolean);
-
+void img_set_format_options (img_window_struct *);
+void img_get_format_options (img_window_struct *);
 #endif
