@@ -57,11 +57,16 @@ img_save_slideshow( img_window_struct *img,
 		gtk_tree_model_get(model, &iter,1,&entry,-1);
 		conf = g_strdup_printf("slide %d",count);
 
-		if( entry->o_filename)
+        if (entry->load_ok)
+            filename = entry->o_filename;
+        else
+            filename = entry->original_filename;
+
+        if (filename)
 		{
 			/* Save original filename and rotation */
 			g_key_file_set_string( img_key_file, conf,
-								   "filename", entry->o_filename);
+								   "filename", filename);
 			g_key_file_set_integer( img_key_file, conf, "angle", entry->angle );
 		}
 		else
@@ -120,6 +125,7 @@ img_save_slideshow( img_window_struct *img,
 		g_key_file_set_integer(img_key_file,conf, "placing",		entry->placing);
 		g_key_file_set_string (img_key_file, conf,"font",			font_desc);
 		g_key_file_set_double_list(img_key_file, conf,"font color",entry->font_color,4);
+        g_key_file_set_double_list(img_key_file, conf,"font bgcolor",entry->font_bgcolor,4);
 		g_free(font_desc);
 		g_free(conf);
 	}
@@ -179,7 +185,7 @@ img_load_slideshow( img_window_struct *img,
 	void (*render);
 	GHashTable *table;
 	gchar      *spath, *conf;
-	gdouble    *color, *font_color;
+	gdouble    *color, *font_color, *font_bgcolor;
 	gboolean    old_file = FALSE;
 	gboolean    first_slide = TRUE;
 
@@ -315,7 +321,11 @@ img_load_slideshow( img_window_struct *img,
 		gsize length;
 		gint anim_id,anim_duration, text_pos, placing, gradient;
 		GdkPixbuf *pix = NULL;
-		gboolean   load_ok;
+        gboolean      load_ok, img_load_ok;
+        gchar *original_filename = NULL;
+        GtkIconTheme *icon_theme;
+        GtkIconInfo  *icon_info;
+        const gchar  *icon_filename;
 		ImgAngle   angle = 0;
 	
 		/* Load project backgroud color */
@@ -338,6 +348,7 @@ img_load_slideshow( img_window_struct *img,
 		{
 			conf = g_strdup_printf("slide %d", i);
 			slide_filename = g_key_file_get_string(img_key_file,conf,"filename", NULL);
+            original_filename = g_strdup (slide_filename);
 
 			if( slide_filename )
 			{
@@ -346,6 +357,26 @@ img_load_slideshow( img_window_struct *img,
 				load_ok = img_scale_image( slide_filename, img->video_ratio,
 										   88, 0, img->distort_images,
 										   img->background_color, &thumb, NULL );
+                img_load_ok = load_ok;
+                if (! load_ok)
+                {
+                    icon_theme = gtk_icon_theme_get_default();
+                    icon_info = gtk_icon_theme_lookup_icon(icon_theme,
+                                                           GTK_STOCK_MISSING_IMAGE,
+                                                           256,
+                                                           GTK_ICON_LOOKUP_FORCE_SVG);
+                    icon_filename = gtk_icon_info_get_filename(icon_info);
+
+
+                    img_message(img, TRUE, _("Slide %i: can't load image %s\n"), i, slide_filename);
+
+                    g_free (slide_filename);
+                    slide_filename = g_strdup(icon_filename);
+                    load_ok = img_scale_image( slide_filename, img->video_ratio,
+                                                88, 0, img->distort_images,
+                                                img->background_color, &thumb, NULL );
+
+                }
 			}
 			else
 			{
@@ -382,6 +413,7 @@ img_load_slideshow( img_window_struct *img,
 				placing 	  = g_key_file_get_integer(img_key_file, conf, "placing",		NULL);
 				font_desc     = g_key_file_get_string (img_key_file, conf, "font", 			NULL);
 				font_color 	  = g_key_file_get_double_list(img_key_file, conf, "font color", NULL, NULL );
+                font_bgcolor  = g_key_file_get_double_list(img_key_file, conf, "font bgcolor", NULL, NULL );
 
 				/* Get the mem address of the transition */
 				spath = (gchar *)g_hash_table_lookup( table, GINT_TO_POINTER( transition_id ) );
@@ -398,6 +430,10 @@ img_load_slideshow( img_window_struct *img,
 													 c_start, c_stop,
 													 p_start, p_stop );
 
+                    /* Handle lod errors */
+                    slide_info->load_ok = img_load_ok;
+                    slide_info->original_filename = original_filename;
+
 					/* If image has been rotated, rotate it now too. */
 					if( angle )
 					{
@@ -436,7 +472,7 @@ img_load_slideshow( img_window_struct *img,
 					img_set_slide_text_info( slide_info, img->thumbnail_model,
 											 &iter, subtitle, anim_id,
 											 anim_duration, text_pos, placing,
-											 font_desc, font_color, img );
+											 font_desc, font_color, font_bgcolor, img );
 
 					/* If we're loading the first slide, apply some of it's
 				 	 * data to final pseudo-slide */
@@ -452,7 +488,10 @@ img_load_slideshow( img_window_struct *img,
 				g_free( font_desc );
 			}
 			else
+            {
 				img->slides_nr--;
+                img_message(img, TRUE, _("Can't load image %s\n"), slide_filename);
+            }
 
 			img_increase_progressbar(img, i);
 			g_free(slide_filename);
