@@ -20,8 +20,6 @@
 #include "support.h"
 #include <glib/gstdio.h>
 
-#define PLUGINS_INSTALLED 0
-
 static gboolean img_plugin_is_loaded(img_window_struct *, GModule *);
 
 GtkWidget *img_load_icon(gchar *filename, GtkIconSize size)
@@ -54,6 +52,17 @@ gchar *img_convert_seconds_to_time(gint total_secs)
 	return g_strdup_printf("%02d:%02d:%02d", h, m, s);
 }
 
+static void
+sens_cell_func( GtkCellLayout   *layout,
+				GtkCellRenderer *cell,
+				GtkTreeModel    *model,
+				GtkTreeIter     *iter,
+				gpointer         data )
+{
+	gboolean sensitive = ! gtk_tree_model_iter_has_child( model, iter );
+	g_object_set( cell, "sensitive", sensitive, NULL );
+}
+
 GtkWidget *_gtk_combo_box_new_text(gboolean pointer)
 {
 	GtkWidget *combo_box;
@@ -64,14 +73,32 @@ GtkWidget *_gtk_combo_box_new_text(gboolean pointer)
 
 	if (pointer)
 	{
-		tree = gtk_tree_store_new (4, GDK_TYPE_PIXBUF, G_TYPE_STRING, G_TYPE_POINTER, G_TYPE_INT);
+		tree = gtk_tree_store_new( 6, GDK_TYPE_PIXBUF,
+									  G_TYPE_STRING,
+									  G_TYPE_POINTER,
+									  G_TYPE_INT,
+									  GDK_TYPE_PIXBUF_ANIMATION,
+									  G_TYPE_BOOLEAN );
 		model = GTK_TREE_MODEL( tree );
 
 		combo_box = gtk_combo_box_new_with_model (model);
 		g_object_unref (G_OBJECT( model ));
-		cell = gtk_cell_renderer_pixbuf_new ();
-		gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (combo_box), cell, FALSE);
-		gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (combo_box), cell, "pixbuf", 0, NULL);
+		cell = img_cell_renderer_anim_new ();
+		gtk_cell_layout_pack_start( GTK_CELL_LAYOUT( combo_box ), cell, FALSE );
+		gtk_cell_layout_set_attributes( GTK_CELL_LAYOUT (combo_box), cell,
+										"anim", 4,
+										NULL );
+		gtk_cell_layout_set_cell_data_func( GTK_CELL_LAYOUT( combo_box ), cell,
+											sens_cell_func, NULL, NULL );
+		
+		cell = gtk_cell_renderer_text_new ();
+		gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (combo_box), cell, TRUE);
+		gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (combo_box), cell,
+										"text", 1,
+										NULL);
+		gtk_cell_layout_set_cell_data_func( GTK_CELL_LAYOUT( combo_box ), cell,
+											sens_cell_func, NULL, NULL );
+		g_object_set(cell, "ypad", (guint)0, NULL);
 	}
 	else
 	{
@@ -80,12 +107,15 @@ GtkWidget *_gtk_combo_box_new_text(gboolean pointer)
 		
 		combo_box = gtk_combo_box_new_with_model (model);
 		g_object_unref (G_OBJECT( model ));
+
+		cell = gtk_cell_renderer_text_new ();
+		gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (combo_box), cell, TRUE);
+		gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (combo_box), cell,
+										"text", 0,
+										NULL);
+		g_object_set(cell, "ypad", (guint)0, NULL);
 	}
 
-	cell = gtk_cell_renderer_text_new ();
-	gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (combo_box), cell, TRUE);
-	gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (combo_box), cell, "text", pointer ? 1 : 0, NULL);
-	g_object_set(cell, "ypad", (guint)0, NULL);
 	return combo_box;
 }
 
@@ -96,23 +126,37 @@ void img_set_statusbar_message(img_window_struct *img_struct, gint selected)
 
 	if (img_struct->slides_nr == 0)
 	{
-		message = g_strdup_printf(_("Welcome to Imagination - %d transitions loaded."),img_struct->nr_transitions_loaded);
-		gtk_statusbar_push(GTK_STATUSBAR(img_struct->statusbar),img_struct->context_id,message);
-		g_free(message);
-		gtk_label_set_text(GTK_LABEL(img_struct->total_slide_number_label),NULL);
+		message = g_strdup_printf(
+				ngettext( "Welcome to Imagination - %d transition loaded.",
+						  "Welcome to Imagination - %d transitions loaded.",
+						  img_struct->nr_transitions_loaded ),
+				img_struct->nr_transitions_loaded );
+		gtk_statusbar_push( GTK_STATUSBAR( img_struct->statusbar ),
+							img_struct->context_id, message );
+		g_free( message );
+		gtk_label_set_text( GTK_LABEL( img_struct->total_slide_number_label ), NULL );
 	}
 	else if (selected)
 	{
-		message = g_strdup_printf(_("%d slides selected"),selected);
-		gtk_statusbar_push(GTK_STATUSBAR(img_struct->statusbar),img_struct->context_id,message);
-		g_free(message);
+		message = g_strdup_printf( ngettext( "%d slide selected",
+											 "%d slides selected",
+											 selected ), selected);
+		gtk_statusbar_push( GTK_STATUSBAR( img_struct->statusbar ),
+							img_struct->context_id, message );
+		g_free( message );
 	}
 	else
 	{
 		total_slides = g_strdup_printf("%d",img_struct->slides_nr);
 		gtk_label_set_text(GTK_LABEL(img_struct->total_slide_number_label),total_slides);
-		message = g_strdup_printf(ngettext("%d slide imported %s" ,"%d slides imported %s",img_struct->slides_nr),img_struct->slides_nr,_(" - Use the CTRL key to select/unselect or SHIFT for multiple select"));
-		gtk_statusbar_push(GTK_STATUSBAR(img_struct->statusbar),img_struct->context_id,message);
+		message = g_strdup_printf( ngettext( "%d slide loaded %s",
+											 "%d slides loaded %s",
+											 img_struct->slides_nr ),
+								   img_struct->slides_nr,
+								   _(" - Use the CTRL key to select/unselect "
+									 "or SHIFT for multiple select") );
+		gtk_statusbar_push( GTK_STATUSBAR( img_struct->statusbar ),
+							img_struct->context_id, message );
 		g_free(total_slides);
 		g_free(message);
 	}
@@ -120,37 +164,40 @@ void img_set_statusbar_message(img_window_struct *img_struct, gint selected)
 
 void img_load_available_transitions(img_window_struct *img)
 {
-	GDir          *dir;
-	const gchar   *transition_name;
-	gchar         *fname = NULL, *name, *filename;
-	gchar        **trans, **bak;
-	GModule       *module;
-	GdkPixbuf     *pixbuf;
 	GtkTreeIter    piter, citer;
 	GtkTreeStore  *model;
 	gpointer       address;
-	gchar         *search_paths[3], **path;
-	void (*plugin_set_name)(gchar **, gchar ***);
+	gchar         *search_paths[3],
+				 **path;
 
-	model = GTK_TREE_STORE(gtk_combo_box_get_model(GTK_COMBO_BOX(img->transition_type)));
+	model = GTK_TREE_STORE( gtk_combo_box_get_model(
+								GTK_COMBO_BOX( img->transition_type ) ) );
 	
 	/* Fill the combo box with no transition */
-	gtk_tree_store_append(model, &piter, NULL);
-	gtk_tree_store_set(model, &piter, 0, NULL, 1, _("None"), 2, NULL, 3, -1, -1);
-	gtk_combo_box_set_active(GTK_COMBO_BOX(img->transition_type), 0);
+	gtk_tree_store_append( model, &piter, NULL );
+	gtk_tree_store_set( model, &piter, 0, NULL,
+									   1, _("None"),
+									   2, NULL,
+									   3, -1,
+									   4, NULL,
+									   -1);
+	gtk_combo_box_set_active( GTK_COMBO_BOX( img->transition_type ), 0 );
 
 	/* Create NULL terminated array of paths that we'll be looking at */
 #if PLUGINS_INSTALLED
-	search_paths[0] = g_strconcat(PACKAGE_LIB_DIR,"/imagination",NULL);
+	search_paths[0] = g_build_path(G_DIR_SEPARATOR_S, PACKAGE_LIB_DIR, "imagination", NULL );
 #else
 	search_paths[0] = g_strdup("./transitions");
 #endif
-	search_paths[1] = g_strconcat( g_get_home_dir(), "/.imagination/plugins", NULL );
+	search_paths[1] = g_build_path(G_DIR_SEPARATOR_S, g_get_home_dir(), ".imagination",
+									"plugins", NULL );
 	search_paths[2] = NULL;
 
 	/* Search all paths listed in array */
 	for( path = search_paths; *path; path++ )
 	{
+		GDir *dir;
+
 		dir = g_dir_open( *path, 0, NULL );
 		if( dir == NULL )
 		{
@@ -160,6 +207,11 @@ void img_load_available_transitions(img_window_struct *img)
 		
 		while( TRUE )
 		{
+			const gchar  *transition_name;
+			gchar        *fname = NULL;
+			GModule      *module;
+			void (*plugin_set_name)(gchar **, gchar ***);
+
 			transition_name = g_dir_read_name( dir );
 			if ( transition_name == NULL )
 				break;
@@ -168,6 +220,10 @@ void img_load_available_transitions(img_window_struct *img)
 			module = g_module_open( fname, G_MODULE_BIND_LOCAL );
 			if( module && img_plugin_is_loaded(img, module) == FALSE )
 			{
+				gchar  *name,
+					  **trans,
+					  **bak;
+
 				/* Obtain the name from the plugin function */
 				g_module_symbol( module, "img_get_plugin_info",
 								 (void *)&plugin_set_name);
@@ -181,38 +237,65 @@ void img_load_available_transitions(img_window_struct *img)
 				/* Add transitions */
 				for( bak = trans; *trans; trans += 3 )
 				{
+					gchar              *pix_name,
+									   *anim_name,
+									   *tmp;
+					GdkPixbuf          *pixbuf;
+					GdkPixbufAnimation *anim;
+					gint                id = GPOINTER_TO_INT( trans[2] );
+
 #if PLUGINS_INSTALLED
-					filename =
-						g_strdup_printf( "%s/imagination/pixmaps/imagination-%d.png",
-										 DATADIR, GPOINTER_TO_INT( trans[2] ) );
+					tmp = g_build_filename( DATADIR, "imagination",
+											"pixmaps", NULL );
 #else /* PLUGINS_INSTALLED */
-					filename =
-						g_strdup_printf( "./pixmaps/imagination-%d.png",
-										 GPOINTER_TO_INT( trans[2] ) );
+					tmp = g_strdup( "./pixmaps" );
 #endif /* ! PLUGINS_INSTALLED */
 
-					pixbuf = gdk_pixbuf_new_from_file(filename, NULL);
+					pix_name = g_strdup_printf( "%s%simagination-%d.png",
+												tmp, G_DIR_SEPARATOR_S, id );
+					anim_name = g_strdup_printf( "%s%simagination-%d.gif",
+												 tmp, G_DIR_SEPARATOR_S, id );
+					g_free( tmp );
+
+					pixbuf = gdk_pixbuf_new_from_file( pix_name, NULL );
 
 					/* Local plugins will fail to load images from system
 					 * folder, so we'll try to load the from home folder. */
 					if( ! pixbuf )
 					{
-						g_free( filename );
-						filename =
-							g_strdup_printf( "%s/.imagination/pixmaps/imagination-%d.png",
-											 g_get_home_dir(),
-											 GPOINTER_TO_INT( trans[2] ) );
-						pixbuf = gdk_pixbuf_new_from_file( filename, NULL );
+						g_free( pixbuf );
+						g_free( anim );
+
+						tmp = g_build_filename( g_get_home_dir(),
+												".imagination",
+												"pixmaps",
+												NULL );
+
+						pix_name =
+							g_strdup_printf( "%s%simagination-%d.png",
+											 tmp, G_DIR_SEPARATOR_S, id );
+						anim_name =
+							g_strdup_printf( "%s%simagination-%d.gif",
+											 tmp, G_DIR_SEPARATOR_S, id );
+						g_free( tmp );
+
+						pixbuf = gdk_pixbuf_new_from_file( pix_name, NULL );
 					}
-					g_free( filename );
+					anim = gdk_pixbuf_animation_new_from_file( anim_name,
+															   NULL );
+					g_free( pix_name );
+					g_free( anim_name );
 					g_module_symbol( module, trans[1], &address );
 					gtk_tree_store_append( model, &citer, &piter );
 					gtk_tree_store_set( model, &citer, 0, pixbuf,
 													   1, trans[0],
 													   2, address,
-													   3, GPOINTER_TO_INT( trans[2] ),
+													   3, id,
+													   4, anim,
 													   -1 );
 					img->nr_transitions_loaded++;
+					g_object_unref( G_OBJECT( pixbuf ) );
+					g_object_unref( G_OBJECT( anim ) );
 				}
 				g_free( bak );
 			}
@@ -233,6 +316,8 @@ void img_show_file_chooser(SexyIconEntry *entry, SexyIconEntryPosition icon_pos,
 	GtkWidget *file_selector;
 	gchar *dest_dir;
 	gint response;
+    GtkFileFilter *video_filter, *all_files_filter;
+    gchar *file_extention, *dot_position, *proposed_filename, *file_basename, *stripped_filename;
 
 	file_selector = gtk_file_chooser_dialog_new (_("Please choose the slideshow project filename"),
 							GTK_WINDOW (img->imagination_window),
@@ -243,6 +328,77 @@ void img_show_file_chooser(SexyIconEntry *entry, SexyIconEntryPosition icon_pos,
 							GTK_RESPONSE_ACCEPT,
 							NULL);
 
+    /* only video files filter */
+    video_filter = gtk_file_filter_new ();
+    switch (img->video_format)
+    {
+        default:
+        case 'V':
+        gtk_file_filter_set_name (video_filter, _("VOB (DVD video)") );
+        gtk_file_filter_add_pattern (video_filter, "*.vob");
+        file_extention = ".vob";
+        break;
+
+        case 'M':
+        gtk_file_filter_set_name (video_filter, _("MP4 (MPEG-4)") );
+        gtk_file_filter_add_pattern (video_filter, "*.mp4");
+        file_extention = ".mp4";
+        break;
+
+        case 'O':
+        gtk_file_filter_set_name (video_filter, _("OGV (Theora/Vorbis)") );
+        gtk_file_filter_add_pattern (video_filter, "*.ogv");
+        file_extention = ".ogv";
+        break;
+
+        case 'F':
+        gtk_file_filter_set_name (video_filter, _("FLV (Flash video)") );
+        gtk_file_filter_add_pattern (video_filter, "*.flv");
+        file_extention = ".flv";
+        break;
+
+        case '3':
+        gtk_file_filter_set_name (video_filter, _("3GP (Mobile Phones)") );
+        gtk_file_filter_add_pattern (video_filter, "*.3gp");
+        file_extention = ".3gp";
+        break;
+    }
+    gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (file_selector), video_filter);
+
+    /* All files filter */
+    all_files_filter = gtk_file_filter_new ();
+    gtk_file_filter_set_name(all_files_filter, _("All files"));
+    gtk_file_filter_add_pattern(all_files_filter, "*");
+    gtk_file_chooser_add_filter(GTK_FILE_CHOOSER(file_selector), all_files_filter);
+    
+    /* Propose a file name */
+    if (img->project_filename)
+    {
+        file_basename = g_path_get_basename(img->project_filename);
+        dot_position = g_strrstr(file_basename, ".");
+        if (NULL != dot_position)
+        {
+            stripped_filename = g_strndup(file_basename, dot_position - file_basename);
+            g_free(file_basename);
+        }
+        else
+        {
+            stripped_filename = file_basename;
+        }
+        proposed_filename = g_strjoin(NULL, stripped_filename, file_extention, NULL);
+        g_free(stripped_filename);
+    }
+    else
+    {
+        proposed_filename = g_strjoin(NULL, "unknown", file_extention, NULL);
+    }
+    gtk_file_chooser_set_current_name(GTK_FILE_CHOOSER (file_selector), proposed_filename);
+    g_free(proposed_filename);
+
+    /* set current dir to the project current dir */
+    if (img->project_current_dir)
+        gtk_file_chooser_set_current_folder(GTK_FILE_CHOOSER(file_selector),img->project_current_dir);
+
 	gtk_file_chooser_set_do_overwrite_confirmation(GTK_FILE_CHOOSER (file_selector),TRUE);
 	response = gtk_dialog_run (GTK_DIALOG(file_selector));
 	if (response == GTK_RESPONSE_ACCEPT)
@@ -282,6 +438,15 @@ img_create_new_slide( void )
 		slide->font_color[1] = 0; /* G */
 		slide->font_color[2] = 0; /* B */
 		slide->font_color[3] = 1; /* A */
+		/* default: no font color background */
+        slide->font_bgcolor[0] = 1; /* R */
+        slide->font_bgcolor[1] = 1; /* G */
+        slide->font_bgcolor[2] = 1; /* B */
+        slide->font_bgcolor[3] = 1; /* A */
+        
+        /* Load error handling */
+        slide->load_ok = TRUE;
+        slide->original_filename = NULL;
 	}
 
 	return( slide );
@@ -426,6 +591,7 @@ img_set_slide_text_info( slide_struct      *slide,
 						 gint               placing,
 						 const gchar       *font_desc,
 						 gdouble           *font_color,
+                         gdouble           *font_bgcolor,
 						 img_window_struct *img )
 {
 	/* Set the slide text info parameters */
@@ -487,6 +653,14 @@ img_set_slide_text_info( slide_struct      *slide,
 		slide->font_color[2] = font_color[2];
 		slide->font_color[3] = font_color[3];
 	}
+
+    if( font_bgcolor )
+    {
+        slide->font_bgcolor[0] = font_bgcolor[0];
+        slide->font_bgcolor[1] = font_bgcolor[1];
+        slide->font_bgcolor[2] = font_bgcolor[2];
+        slide->font_bgcolor[3] = font_bgcolor[3];
+    }
 }								
 
 void
@@ -498,6 +672,7 @@ img_free_slide_struct( slide_struct *entry )
 		g_unlink( entry->r_filename );
 	g_free(entry->o_filename);
 	g_free(entry->r_filename);
+    g_free(entry->original_filename);
 	g_free(entry->resolution);
 	g_free(entry->type);
 	
@@ -961,3 +1136,43 @@ img_scale_gradient( gint              gradient,
 	return( TRUE );
 }
 
+/* Prints a message in the message tab */
+void
+img_message (img_window_struct *img,
+             gboolean alert_user,
+             gchar *message, ...)
+{
+        GtkTextIter message_end;
+        va_list args;
+        char *parsed_message;
+        int parsed_message_size = 0;
+
+        va_start (args, message);
+        parsed_message_size = vsnprintf(NULL, 0, message, args);
+        va_end(args);
+        /* if we have a glibc 2.0, just print the first 500 char */
+        if (-1 == parsed_message_size)
+            parsed_message_size = 500;
+        parsed_message = malloc(parsed_message_size + 1);
+
+//        vprintf(message, args);
+        va_start(args, message);
+        vsnprintf(parsed_message, parsed_message_size + 1, message, args);
+        va_end(args);
+
+        gtk_text_buffer_get_end_iter(img->message_buffer, &message_end);
+        gtk_text_buffer_insert(img->message_buffer, &message_end,
+                               parsed_message, -1);
+
+        free(parsed_message);
+
+        if (alert_user)
+        {
+            PangoAttrList *   pango_list = pango_attr_list_new();
+            PangoAttribute *  pango_attr = pango_attr_weight_new (PANGO_WEIGHT_BOLD);
+            pango_attr_list_insert(pango_list, pango_attr);
+            gtk_label_set_attributes(GTK_LABEL(img->message_label), pango_list);
+            pango_attr_list_unref (pango_list);
+        }
+
+}
