@@ -20,6 +20,8 @@
 #ifndef __IMAGINATION_SUPPORT_H
 #define __IMAGINATION_SUPPORT_H
 
+#define PLUGINS_INSTALLED 0
+
 #ifdef HAVE_CONFIG_H
 #  include <config.h>
 #endif
@@ -30,6 +32,7 @@
 #include <math.h>
 #include "imagination.h"
 #include "sexy-icon-entry.h"
+#include "imgcellrendereranim.h"
 
 #ifdef ENABLE_NLS
 #  include <glib/gi18n.h>
@@ -46,7 +49,7 @@
 
 GtkWidget *img_load_icon(gchar *, GtkIconSize );
 gchar *img_convert_seconds_to_time(gint );
-GtkWidget *_gtk_combo_box_new_text(gboolean);
+GtkWidget *_gtk_combo_box_new_text(gint);
 void img_set_statusbar_message(img_window_struct *, gint);
 void img_load_available_transitions(img_window_struct *);
 void img_show_file_chooser(SexyIconEntry *, SexyIconEntryPosition, int, img_window_struct *);
@@ -100,6 +103,7 @@ img_set_slide_text_info( slide_struct      *slide,
 						 gint               placing,
 						 const gchar       *font_desc,
 						 gdouble           *font_color,
+                         gdouble           *font_bgcolor,
 						 img_window_struct *img );
 
 void img_free_slide_struct( slide_struct * );
@@ -144,4 +148,9 @@ img_scale_gradient( gint              gradient,
 					GdkPixbuf       **pixbuf,
 					cairo_surface_t **surface );
 
+void
+img_message (img_window_struct *img,
+             gboolean alert_user,
+             gchar *message, ...);
+
 #endif
